@@ -1,6 +1,8 @@
 """Utilities related to handling / interacting with wheel files."""
 
+import base64
 import contextlib
+import csv
 import hashlib
 import io
 import os
@@ -129,7 +131,7 @@ def copyfileobj_with_hashing(
         dest.write(buf)
         size += len(buf)
 
-    return hasher.hexdigest(), size
+    return base64.urlsafe_b64encode(hasher.digest()).decode("ascii").rstrip("="), size
 
 
 def get_launcher_kind() -> "LauncherKind":  # pragma: no cover
@@ -192,11 +194,14 @@ def construct_record_file(
 
     :return: A stream that can be written to file. Must be closed by the caller.
     """
-    stream = io.BytesIO()
+    stream = io.TextIOWrapper(
+        io.BytesIO(), encoding="utf-8", write_through=True, newline=""
+    )
+    writer = csv.writer(stream, delimiter=",", quotechar='"', lineterminator="\n")
     for scheme, record in records:
-        stream.write(record.to_line(prefix_for_scheme(scheme)) + b"\n")
+        writer.writerow(record.to_row(prefix_for_scheme(scheme)))
     stream.seek(0)
-    return stream
+    return stream.detach()
 
 
 def parse_entrypoints(text: str) -> Iterable[Tuple[str, str, str, "ScriptSection"]]:
